.dashboard {
	display: grid;
	grid-template-columns: 1fr 3fr;
	gap: 2%;
}

.side-bar p {
	margin-bottom: 2px;
}

dt {
	font-weight: bold;
}

dd {
	margin-bottom: 20px;
}

a {
	text-decoration: underline;
	color: steelblue;
}

a:hover {
	text-decoration: none;
	color: darkcyan;
}

h1 {
	margin: 0% 5%;
	font-style: oblique;
}

@media screen and (max-width:800px) {
	.dashboard {
		display: block;
		margin: 5%;
	}
	.side-bar {
		max-width: 70%;
		margin: 5%;
	}
	.ts-app {
		overflow-x: auto;
		width: 700px;
	}
}

.button {
	background-color: slategrey;
	padding: 15px 40px;
	border: none;
	margin: 2%;
	font-size: 0.8em;
	text-decoration: none;
	color: #fff;
}

.button:hover {
	background-color: #404040;
	box-shadow: 5px 10px 10px #222;
}

footer {
	margin: 10% auto;
}

img {
	width: 100%;
}

/* Hover Bob */

@-webkit-keyframes hvr-bob {
	0% {
		-webkit-transform: translateY(-8px);
		transform: translateY(-8px);
	}
	50% {
		-webkit-transform: translateY(-4px);
		transform: translateY(-4px);
	}
	100% {
		-webkit-transform: translateY(-8px);
		transform: translateY(-8px);
	}
}

@keyframes hvr-bob {
	0% {
		-webkit-transform: translateY(-8px);
		transform: translateY(-8px);
	}
	50% {
		-webkit-transform: translateY(-4px);
		transform: translateY(-4px);
	}
	100% {
		-webkit-transform: translateY(-8px);
		transform: translateY(-8px);
	}
}

@-webkit-keyframes hvr-bob-float {
	100% {
		-webkit-transform: translateY(-8px);
		transform: translateY(-8px);
	}
}

@keyframes hvr-bob-float {
	100% {
		-webkit-transform: translateY(-8px);
		transform: translateY(-8px);
	}
}

.hvr-bob {
	display: inline-block;
	vertical-align: middle;
	-webkit-transform: perspective(1px) translateZ(0);
	transform: perspective(1px) translateZ(0);
	box-shadow: 0 0 1px rgba(0, 0, 0, 0);
}

.hvr-bob:hover, .hvr-bob:focus, .hvr-bob:active {
	-webkit-animation-name: hvr-bob-float, hvr-bob;
	animation-name: hvr-bob-float, hvr-bob;
	-webkit-animation-duration: .3s, 1.5s;
	animation-duration: .3s, 1.5s;
	-webkit-animation-delay: 0s, .3s;
	animation-delay: 0s, .3s;
	-webkit-animation-timing-function: ease-out, ease-in-out;
	animation-timing-function: ease-out, ease-in-out;
	-webkit-animation-iteration-count: 1, infinite;
	animation-iteration-count: 1, infinite;
	-webkit-animation-fill-mode: forwards;
	animation-fill-mode: forwards;
	-webkit-animation-direction: normal, alternate;
	animation-direction: normal, alternate;
	color: beige;
}